﻿#pragma TextEncoding = "UTF-8"
#pragma rtGlobals=3		// Use modern global access method and strict wave access.

// This function adds APPEND lines to a Splice Intervals table. 10/04/2017			//updated to add prompt about Splice Ties conversion.

	Function AppendCore2SpliceIntervalTable( )
		SetDataFolder root:
			String/G G_Hole
			String Hole = G_Hole, Site, HoleLetter, SpliceTie2Int, SpliceInt2Tie
			Variable/G G_Core, G_Offset
			Variable Core = G_Core, Offset = G_Offset, i
			Prompt Hole, "Hole"
			Prompt Core, "Core Number"
			Prompt SpliceTie2Int, "Do you want to first convert Splice Ties to Splice Intervals?\r(select yes if you have been revising the splice using the Splice Tie Table)", popup, "No;Yes"					//Gives the user the chance to first convert splice ties to splice interval. 
			Prompt SpliceInt2Tie, "Once the core is appended to the Splice Interval, do you want to convert Splice Interval to Splice Ties?\r(select yes if you like to update the Splice Tie Table to include the appended cores)", popup, "No;Yes"					//Gives the user the chance to convert splice intervals to splice ties at the end of the function. 
			DoPrompt "AppendCore2SpliceIntervalTable", Hole, Core, SpliceTie2Int, SpliceInt2Tie
			G_Hole = Hole; G_Core = Core
			AbortOnValue V_Flag, 0
			Site = RemoveEnding( Hole )
			HoleLetter = Hole[ StrLen( Hole ) -1 ]
			
			If(Cmpstr(SpliceTie2Int,"Yes",1)==0)					//Should run Splice_Tie_Data_2_Intervals_F( Site ) if the user selected "Yes" to convert ties to intervals
				Splice_Tie_Data_2_Intervals_F( Site )
			EndIf
			
			DFREF SplFldr = $Site + "_Splice_Intervals"
			WAVE Matrix = $Hole + "_Coring_Matrix"
			If( DimSize( Matrix, 0 ) <= Core ) // Checks to see if we are at the end of the cores for matrices that are truncated at the bottom core
				ABORT Hole + "_Coring_Matrix ends at Core " + Num2Str( DimSize( Matrix, 0 ) - 1 )
			EndIf
			Make/O/N = ( DimSize( Matrix, 1 ) ) MatrixCoreLine // This line and the next copy 1 line of the coring matrix into a separate wave for subsequent processing
			MatrixCoreLine[ ] = Matrix[ Core ][ p ] 
			WaveStats/Q MatrixCoreLine // The stats such as V_MaxLoc and V_MinLoc are used below to fill out values in the table
			If( V_NumNaNs == DimSize( Matrix, 1 ) ) // If there was no recovery this If statement stops adding another line to the splice table
				ABORT "The are no data in " + NameOfWave( Matrix ) + " for Core " + Num2Str( Core )
			Endif
			If( SpliceDataCheck( Site, "Splice_Intervals" ) ) // Checks to see that all of the columns in the splice interval table are of equal length
				ABORT
			EndIf
		SetDataFolder SplFldr
			WAVE Site_Top
			Variable NextLine = NumPnts( Site_Top )
			String SplTextWvList = SortList( WaveList( "*", ";", "TEXT:1" ) )
			For( i = 0; i < ItemsInList( SplTextWvList ); i += 1 ) // This processes a list of Text waves in the splice interval table
				WAVE/T SplTextWv = $StringFromList( i, SplTextWvList ) // SplWv gets reused for each text wave
				InsertPoints NextLine, 1, SplTextWv // Adds a line at the bottom of each text wave
				StrSwitch( NameOfWave( SplTextWv ) )
					Case "Site_Top":
						SplTextWv[ NextLine ] = Site
						Break
					Case "Hole_Top":
						SplTextWv[ NextLine ] = Holeletter
						Break
					Case "Type_Top":
						SplTextWv[ NextLine ] = "H"
						Break
					Case "Tie":
						SplTextWv[ NextLine ] = "APPEND"
						Break
				EndSwitch
			EndFor
			String SplWvList = SortList( WaveList( "*", ";", "TEXT:0" ) )
			For( i = 0; i < ItemsInList( SplWvList ); i += 1 ) // This processes a list of numerical waves in the splice interval table
				WAVE SplWv = $StringFromList( i, SplWvList ) // SplWv gets reused for each numerical wave
				InsertPoints NextLine, 1, SplWv // Adds a line at the bottom of each numerical wave
				StrSwitch( NameOfWave( SplWv ) )
					Case "Core_Top":
						SplWv[ NextLine ] = Core
						Break
					Case "Section_Top":
						SplWv[ NextLine ] =  1
						SplWv[ NextLine ] = V_MinLoc
						Break
					Case "Interval_Top":
						SplWv[ NextLine ] = 0
						Break
					Case "CSF_Top":
						SplWv[ NextLine ] = Matrix[ Core ][ V_MinLoc ][ 0 ] +.001 // These 1 mm add-ons are used because these are floating point
						Break																						//  numbers and the function needs to be sure that they are a little more ( less )
					Case "CCSF_Top":																			//  than the matrix values used to scale images. Otherwise - possible error in Splice_Images()
						SplWv[ NextLine ] = Matrix[ Core ][ V_MinLoc ][ 2 ] + .001
						Break
					Case "Section_Bottom":
						SplWv[ NextLine ] = V_MaxLoc
						Break
					Case "Interval_Bottom":
						SplWv[ NextLine ] = Matrix[ Core ][ V_MaxLoc ][ 1 ] * 100
						Break
					Case "CSF_Bottom":
						SplWv[ NextLine ] = Matrix[ Core ][ V_MaxLoc ][ 0 ] + Matrix[ Core ][ V_MaxLoc ][ 1 ] - .001
						Break
					Case "CCSF_Bottom":
						SplWv[ NextLine ] = Matrix[ Core ][ V_MaxLoc ][ 2 ] + Matrix[ Core ][ V_MaxLoc ][ 1 ] - .001
						Break
				EndSwitch
			EndFor
		SetDataFolder root:		
			KillWaves MatrixCoreLine
			G_Core += 1 // Next time the function is called the core number is incremented by 1
			
			If(Cmpstr(SpliceInt2Tie,"Yes",1)==0)					//Should run Splice_Interval_Data_2_Ties_F( Site ) if the user selected "Yes" to convert interval to ties
				Splice_Interval_Data_2_Ties_F( Site )
			EndIf
	End





==================================================================================================================================================================
==================================================================================================================================================================

// This function adds APPEND lines to a Splice Intervals table. 10/04/2017

//	Function AppendCore2SpliceIntervalTable( )				//original backup
		SetDataFolder root:
			String/G G_Hole
			String Hole = G_Hole, Site, HoleLetter
			Variable/G G_Core, G_Offset
			Variable Core = G_Core, Offset = G_Offset, i
			Prompt Hole, "Hole"
			Prompt Core, "Core Number"
			DoPrompt "AppendCore2SpliceIntervalTable", Hole, Core
			G_Hole = Hole; G_Core = Core
			AbortOnValue V_Flag, 0
			Site = RemoveEnding( Hole )
			HoleLetter = Hole[ StrLen( Hole ) -1 ]
			DFREF SplFldr = $Site + "_Splice_Intervals"
			WAVE Matrix = $Hole + "_Coring_Matrix"
			If( DimSize( Matrix, 0 ) <= Core ) // Checks to see if we are at the end of the cores for matrices that are truncated at the bottom core
				ABORT Hole + "_Coring_Matrix ends at Core " + Num2Str( DimSize( Matrix, 0 ) - 1 )
			EndIf
			Make/O/N = ( DimSize( Matrix, 1 ) ) MatrixCoreLine // This line and the next copy 1 line of the coring matrix into a separate wave for subsequent processing
			MatrixCoreLine[ ] = Matrix[ Core ][ p ] 
			WaveStats/Q MatrixCoreLine // The stats such as V_MaxLoc and V_MinLoc are used below to fill out values in the table
			If( V_NumNaNs == DimSize( Matrix, 1 ) ) // If there was no recovery this If statement stops adding another line to the splice table
				ABORT "The are no data in " + NameOfWave( Matrix ) + " for Core " + Num2Str( Core )
			Endif
			If( SpliceDataCheck( Site, "Splice_Intervals" ) ) // Checks to see that all of the columns in the splice interval table are of equal length
				ABORT
			EndIf
		SetDataFolder SplFldr
			WAVE Site_Top
			Variable NextLine = NumPnts( Site_Top )
			String SplTextWvList = SortList( WaveList( "*", ";", "TEXT:1" ) )
			For( i = 0; i < ItemsInList( SplTextWvList ); i += 1 ) // This processes a list of Text waves in the splice interval table
				WAVE/T SplTextWv = $StringFromList( i, SplTextWvList ) // SplWv gets reused for each text wave
				InsertPoints NextLine, 1, SplTextWv // Adds a line at the bottom of each text wave
				StrSwitch( NameOfWave( SplTextWv ) )
					Case "Site_Top":
						SplTextWv[ NextLine ] = Site
						Break
					Case "Hole_Top":
						SplTextWv[ NextLine ] = Holeletter
						Break
					Case "Type_Top":
						SplTextWv[ NextLine ] = "H"
						Break
					Case "Tie":
						SplTextWv[ NextLine ] = "APPEND"
						Break
				EndSwitch
			EndFor
			String SplWvList = SortList( WaveList( "*", ";", "TEXT:0" ) )
			For( i = 0; i < ItemsInList( SplWvList ); i += 1 ) // This processes a list of numerical waves in the splice interval table
				WAVE SplWv = $StringFromList( i, SplWvList ) // SplWv gets reused for each numerical wave
				InsertPoints NextLine, 1, SplWv // Adds a line at the bottom of each numerical wave
				StrSwitch( NameOfWave( SplWv ) )
					Case "Core_Top":
						SplWv[ NextLine ] = Core
						Break
					Case "Section_Top":
						SplWv[ NextLine ] =  1
						SplWv[ NextLine ] = V_MinLoc
						Break
					Case "Interval_Top":
						SplWv[ NextLine ] = 0
						Break
					Case "CSF_Top":
						SplWv[ NextLine ] = Matrix[ Core ][ V_MinLoc ][ 0 ] +.001 // These 1 mm add-ons are used because these are floating point
						Break																						//  numbers and the function needs to be sure that they are a little more ( less )
					Case "CCSF_Top":																			//  than the matrix values used to scale images. Otherwise - possible error in Splice_Images()
						SplWv[ NextLine ] = Matrix[ Core ][ V_MinLoc ][ 2 ] + .001
						Break
					Case "Section_Bottom":
						SplWv[ NextLine ] = V_MaxLoc
						Break
					Case "Interval_Bottom":
						SplWv[ NextLine ] = Matrix[ Core ][ V_MaxLoc ][ 1 ] * 100
						Break
					Case "CSF_Bottom":
						SplWv[ NextLine ] = Matrix[ Core ][ V_MaxLoc ][ 0 ] + Matrix[ Core ][ V_MaxLoc ][ 1 ] - .001
						Break
					Case "CCSF_Bottom":
						SplWv[ NextLine ] = Matrix[ Core ][ V_MaxLoc ][ 2 ] + Matrix[ Core ][ V_MaxLoc ][ 1 ] - .001
						Break
				EndSwitch
			EndFor
		SetDataFolder root:		
			KillWaves MatrixCoreLine
			G_Core += 1 // Next time the function is called the core number is incremented by 1
	End
