﻿#pragma TextEncoding = "UTF-8"
#pragma rtGlobals=3		// Use modern global access method and strict wave access.


	Function NewAgeSpectrogram( )
		SetDataFolder root:
			String/G G_Data_Wave, G_OutPutName, G_XAxis
			String Data = G_Data_Wave, OutPutName = G_OutPutName, XAxis = G_XAxis
			Variable/G G_S_end, G_S_start, G_Jump, G_Taper_Length, G_Fit, G_Segment_Length, G_Sed_Rate
			Variable i = 0, Interval//, Taper_Length = G_Taper_Length, Fit = G_Fit;
			Variable Points, S_end = G_S_end, S_start = G_S_start, Jump = G_Jump, P_Start;
			Variable Segment_Points,  Segment_Length = G_Segment_Length;
			String/G G_DataFolder
			String DataFolder = G_DataFolder
			Prompt DataFolder, "DataFolder", popup, "root:;" + FolderList( "*" )
			DoPrompt "Spetrogram", DataFolder;
			G_DataFolder = DataFolder; AbortOnValue V_Flag, 0
		SetDataFolder $DataFolder
			Prompt Data, "Data Wave (evenly spaced data):", popup, WaveList("*_I*",";","") // The evenly spaced data has "_I" ( for interpolated ) as part of its name
			Prompt Segment_Length, "Segment Length (my): " // The default age scale in my
			Prompt S_start, "Starting Point (Ma):"; //
			Prompt S_end, "Ending Point (Ma):";
			Prompt Jump, "Jump (my):"; // How much time between individual spectra that make up the spectrogram
			Prompt OutPutName, "Output Name?:" // User supplies a name that will be used for a datafolder to hold the results
			Prompt XAxis, "X Axis:", popup, "Age;Freq" // The X axis can be either age or frequency
			DoPrompt "SPECTROGRAM", Data, Segment_Length, S_Start, S_End, Jump, OutPutName, XAxis; AbortOnValue V_Flag, 0
			G_OutPutName = OutPutName; G_Segment_Length = Segment_Length; G_S_start = S_start;
			G_S_end = S_end; G_Jump = Jump; G_Data_Wave = Data; G_XAxis = XAxis	
			Print "NewAgeSpectrogram_F( \"" + DataFolder + "\", \"" + Data + "\",", Segment_Length,",", S_Start,",", S_End,",", Jump,", \"" + OutPutName + "\", \"" + XAxis + "\" )"
			NewAgeSpectrogram_F( DataFolder, Data, Segment_Length, S_Start, S_End, Jump, OutPutName, XAxis )
	End

----------------------------------------

	Function NewAgeSpectrogram_F( DataFolder, Data, Segment_Length, S_Start, S_End, Jump, OutPutName, XAxis )
			String DataFolder, Data, OutPutName, XAxis
			Variable S_end, S_start, Jump, Segment_Length
		SetDataFolder root:
			Variable/G G_S_End, G_Sed_Rate
			Variable i = 0, Interval
			Variable Points, P_Start;
			Variable Segment_Points, Total_Points
		SetDataFolder $DataFolder
			WAVE DataWave = $Data // Wave ref for the data to be processed into a spectrogram
			Segment_Points = Segment_Length / DimDelta( DataWave, 0 ) // Calculate the size in points of a segment based on the segment length and the sampling interval of the data wave
			Total_Points = 2 ^ ( PowerOf2( Segment_Points ) ) // This pads the segment to be processed to the next highest power of 2
			Variable JumpPnts = Jump / dimdelta( DataWave,0 ) // Calculate how many points to shift for each segment
			If( S_End > RightX( DataWave ) ) // Check to see if the data are old enough to cover the age range selected by the user
				S_End = RightX( DataWave ) // If the requested oldest age is > the data oldest poiont, reset the age range to the oldest data
				G_S_End = RightX( DataWave )
				DoAlert 1, "The ending Age you have chosen is deeper than the bottom of the data wave.\rThe end Age will be reset to the bottom of the data wave.\r\rDo you want to continue?" 
				If( V_Flag == 2 )
					ABORT
				EndIf
			EndIf
			Print "Segment Span in Points:", Round( Segment_Points ), ",  in Age:", Segment_Length, "m"
			Print "Total Points in the FFT segments:", Total_Points
			Print "Jump in Points:", Round( JumpPnts )
			Print "Start", S_Start, "  End", S_End

// This section reflects the first segment and last segment at either end of the datawave

			Duplicate/O/R = [ 0, ( Segment_Points ) ] DataWave, DataWvPlus // Make a new segment wave
			DeletePoints 0, 1, DataWvPlus
			Variable DataWvPlusBottom = RightX( DataWvPlus )
			Reverse DataWvPlus
			SetScale/P x -DataWvPlusBottom, DimDelta( DataWave, 0 ), DataWvPlus
			Variable Delta = RightX( DataWvPlus ) - LeftX( DataWave ) 
			SetScale/P x, ( -DataWvPlusBottom - Delta ), DimDelta( DataWave, 0 ), DataWvPlus
			Concatenate/NP { DataWave }, DataWvPlus
			Variable NPnts = NumPnts( DataWvPlus )
			Duplicate/O/R = [ NPnts - 1, NPnts - Segment_Points ] DataWvPlus, Temp
			Reverse Temp
			DeletePoints 0, 1, Temp
			Concatenate/NP { Temp }, DataWvPlus
			KillWaves Temp

		SetDataFolder root:Xtras
			WAVE Freq, Ones, Period
			Interval = DimDelta( DataWave, 0 )
			Points = NumPnts( DataWave )
			Make/O/N = ( ( Total_Points / 2) + 1 ) Power;
			Variable SpectYSize = ( S_End - S_Start ) / Jump
			Make/O/N=( ( ( Total_Points / 2 ) + 1 ) , ( SpectYSize + 1 ) ) Pmatrix, Nmatrix;
			SetScale/P y S_Start, Jump, PMatrix, NMatrix
			Pmatrix = NaN;
			Nmatrix = NaN;
			Variable SpectrumAge = S_Start, SegPointStart, SegAgeStart, SegPointEnd, SegAgeEnd
			PauseUpdate	

// This section sets up the scales for Power and the Spectrograms

			SegAgeStart = SpectrumAge - ( 0.5 * Segment_Length )
			SegPointStart = X2Pnt( DataWvPlus, SegAgeStart )			
			SegAgeEnd = SpectrumAge + ( 0.5 * Segment_Length )
			SegPointEnd = X2Pnt( DataWvPlus, SegAgeEnd )			
			Duplicate/O/R = ( SegAgeStart , SegAgeEnd ) DataWvPlus  Section, FFTSegment
			Hanning FFTSegment
			Redimension/N = ( Total_Points ) FFTSegment;
			FFT/MAGS /DEST = Power FFTSegment;
			CopyScales Power Pmatrix, Nmatrix;

// This loop calculates the successive spectra

			For( i = 0; SpectrumAge <= S_End; i += 1 )
				SegAgeStart = SpectrumAge - ( 0.5 * Segment_Length )
				SegPointStart = X2Pnt( DataWvPlus, SegAgeStart )			
				SegAgeEnd = SpectrumAge + ( 0.5 * Segment_Length )
				SegPointEnd = X2Pnt( DataWvPlus, SegAgeEnd )			
				Duplicate/O/R = ( SegAgeStart , SegAgeEnd ) DataWvPlus  Section, FFTSegment
//				Correlate/Auto FFTSegment, FFTSegment; // This process can be used instead of the Hanning Filter or in addition to Hanning
				Hanning FFTSegment // Hanning filters the data segment with a modified Gaussian curve, bringing the endpoints to 0
				Redimension/N = ( Total_Points ), FFTSegment;
//				FFT/MAG /DEST = Power FFTSegment; // This is for Magnitude.
				FFT/MAGS /DEST = Power FFTSegment; // This is for Magntude Squared ( Power ), which enhances higher peaks.
				PMatrix[ ] [ i ] = Power[ p ];
				Variable PowerMax = WaveMax( Power )
				Power /= PowerMax
//				Smooth 1, Power // Smoothing the spectra can make it a little easier to pick peaks in complicated data
				Nmatrix[ ] [ i ] = Power[ p ];
				SpectrumAge += Jump
			EndFor
			NOTE NMatrix,"Spectrogram_F( \"" +DataFolder+"\", \""+Data+"\","+Num2Str(Segment_Length)+","+Num2Str(S_Start)+","+ Num2Str(S_End)+","+Num2Str(Jump)+", \""+OutPutName+"\" )"
		NewDataFolder/O/S $"root:" + OutPutName
				Duplicate/O NMatrix $OutPutName + "_NormAmp" + XAxis
				Duplicate/O PMatrix $OutPutName + "_RawAmp" + XAxis
		SetDataFolder root:
			KillWaves/Z DataWvPlus, FFTSegment, Section
			If( StringMatch( XAxis, "Freq" ) )
				If( !StrLen( WinList( "NormAmpFreq", ";", "" ) ) )
					NormFreqAmp( DataWave )
				Else
					DoWindow/F NormAmpFreq			
				EndIf
				SetAxis/R AgeAxis S_End, S_Start
				SetAxis FreqAxis 0, 125
			Else	
				If( !StrLen( WinList( "NormAmpAge", ";", "" ) ) )
					NormAgeAmp( DataWave )
				Else
					DoWindow/F NormAmpAge			
				EndIf
				SetAxis/R AgeAxis S_Start, S_End
				SetAxis FreqAxis 0, 125
				ModifyGraph width={Aspect,1.778} 
			EndIf
			DoWindow/H
	End		

----------------------------------------