#pragma rtGlobals=3		// Use modern global access method and strict wave access.

Macro SedVar(CaCO3_AR, Diatom_AR)
	String CaCO3_AR, Diatom_AR
	Prompt CaCO3_AR, "CaCO3 Accumulation Rate Curve:", popup, WaveList("*_AR",";","")
	Prompt Diatom_AR, "Diatom Accumulation Rate Curve:", popup, WaveList("*_AR",";","")

	Silent 1
	PauseUpdate
	
	Variable kYrs//=5000, CaCO3_AR, Diatom_AR, Rad_AR, Clay_AR
	kYrs = NumPnts($CaCO3_AR)

// Variability in Diatom AR for different Milankovic cycles
	Variable Var_19, Var_23, Var_41, Var_100
	Var_19 = 0.05; Var_23 = 0.10; Var_41 = 0.10; Var_100 = 0.15

// The increments are the effects of each cycle for each kyr
	Make/O/N=(KYrs) Inc_19, Inc_23, Inc_41, Inc_100, Inc_Total, Age
	Age = x
	Inc_19 = sin( (Age*2*pi) / 19 ) * Var_19
	Inc_23 = sin( (Age*2*pi) / 23 ) * Var_23
	Inc_41 = sin( (Age*2*pi) / 41 ) * Var_41
	Inc_100 = sin( (Age*2*pi) / 100 ) * Var_100
	Inc_Total = Inc_19 + Inc_23 + Inc_41 + Inc_100

// CaCO3_Vol, Diatom_Vol, etc are volumes of each component from
// dividing the AR by the density
	Make/O/N=(KYrs) CaCO3_Vol, Diatom_Vol, Rad_Vol, Clay_Vol
	CaCO3_Vol = ( CaCO3_AR/2.72 )
	Diatom_Vol = ( Diatom_AR/2.20 ) * ( 1 + Inc_Total )

	Make/O/N=(kYrs) Depth, Porosity, Compacted_Vol
	Depth = NaN; Porosity = NaN; Compacted_Vol = NaN
	Variable H2O_Vol, Total_Volume
	H2O_Vol = ( PhiCaCO3(0)*CaCO3_Vol[0] ) / ( 1 - PhiCaCO3(0) )
	H2O_Vol += ( PhiDiatom(0)*Diatom_Vol[0] ) / ( 1 - PhiDiatom(0) )
	Total_Volume = H2O_Vol + CaCO3_Vol[0] + Diatom_Vol[0]
	Depth[0] = 0
	Porosity[0] = H2O_Vol / Total_Volume
	Compacted_Vol[0] = Total_Volume
	Depth[1] = Total_Volume / 100
	WaveStats/Q Compacted_Vol
	Variable i = 1

	Do
		H2O_Vol = ( PhiCaCO3(V_Sum)*CaCO3_Vol[i] ) / ( 1 - PhiCaCO3(V_Sum) )
		H2O_Vol += ( PhiDiatom(V_Sum)*Diatom_Vol[i] ) / ( 1 - PhiDiatom(V_Sum) )
		Total_Volume = H2O_Vol + CaCO3_Vol[i] + Diatom_Vol[i]
		Porosity[i] = H2O_Vol / Total_Volume
		Compacted_Vol[i] = Total_Volume
		WaveStats/Q Compacted_Vol
		V_Sum /= 100  // Convert from cm to m
		Depth[i+1] = V_Sum
		i+=1
	While( i < kYrs )
EndMacro