﻿#pragma TextEncoding = "UTF-8"
#pragma rtGlobals=3		// Use modern global access method and strict wave access.

// These functions perform a Wigner transform ( similar to Wavelet ) and form a
//		line-by-line normalized version of the output.
	
	Menu "Macros"
		"Wig"
	End


	Function Wig( )
		SetDataFolder root:
			String/G G_DataWave, G_Folder, G_Name, G_YesOrNo
			Variable/G G_Width
			Variable Width = G_Width, PwrOf2, DataPoints
			String DataWave = G_DataWave, Folder = G_Folder, Name = G_Name, YesOrNo = G_YesOrNo
			Prompt Folder, "Data Folder", popup, "root:;" + FolderList( "*" )
			DoPrompt "Wig", Folder; AbortOnValue V_Flag, 0
			G_Folder = Folder
		SetDataFolder $Folder
			Prompt DataWave, "Evenly Spaced Data Wave ", popup, WaveList( "*", ";", "" )
			Prompt Width, "Width of Spectral Window ( meters or time )"
			Prompt Name, "Output Spectrogram Name"
			Prompt YesOrNo, "Calculate Normalized Spectrogram?", popup, "Yes;No"
			DoPrompt "Wig", DataWave, Width, Name, YesOrNo; AbortOnValue V_Flag, 0
			G_DataWave = DataWave; G_Width = Width; G_Name = Name; G_YesOrNo = YesOrNo
			WAVE DWv = $DataWave
		SetDataFolder root:
			Duplicate/O DWv DataWv
			DataPoints = NumPnts( DataWv )
			PwrOf2 = Ceil( log( DataPoints )/ log( 2 ) )  // This line finds the lowest power of 2 that is larger than the # of points in the data wave
			Redimension/N = ( 2 ^ PwrOf2 ) DataWv // The data wave is padded to the next power of 2
		SetDataFolder root:
//			WignerTransform/Wide = 500/Dest = $Name DataWv
			WignerTransform/Gaus=( Width ) /Dest = $Name DataWv
			WAVE RawSpect = $Name
			Redimension/N = ( DataPoints, DimSize( RawSpect, 1 )/3 ) RawSpect // After the transform runs, the output image is reduced in
			KillWaves/Z DataWv																						// X direction to the original data length and by 2/3 in the Y direction
			Preferences 1
			If( StrSearch( WinList("*",";","WIN:1"), Name + "Plot", 0 )  == -1 )
				Display;DelayUpdate
				AppendImage RawSpect;DelayUpdate
				ModifyImage $Name ctab= {*,*,Terrain,0}
				DoWindow/C $Name + "Plot"
			EndIf
			If( StringMatch( YesOrNo, "Yes" ) )
				WigNorm( Name )
			EndIf
	End

--------------------------------------------------------------
	
	Function WigNorm( Name )
		String Name
		SetDataFolder root:
			PauseUpdate
			WAVE RawWigner = $Name
			Make/O/N = ( DimSize( RawWigner, 1 ) ) TimeSlice
			Variable i
			Duplicate/O RawWigner $Name + "Norm"
			WAVE NormWigner = $Name + "Norm"
			NormWigner = NaN
			For( i = 0; i < DimSize( NormWigner, 0 ); i += 1 )
				TimeSlice = RawWigner[i][p] 
				WaveStats/Q TimeSlice
 				TimeSlice/= V_Max
				NormWigner[(i)][] = TimeSlice[q]
			EndFor
			If( StrSearch( winlist("*",";","WIN:1"), Name + "NormPlot", 0 )  == -1 )
				DoUpdate;
				Display;DelayUpdate
				AppendImage $Name+"Norm";DelayUpdate
				ModifyImage $Name+"Norm" ctab= {*,*,Terrain,0}
				DoWindow/C $Name + "NormPlot"
			EndIf
	End

--------------------------------------------------------------
		
	
	Proc WignerPlotStyle() : GraphStyle
		Preferences 1
		PauseUpdate; Silent 1		// modifying window...
		ModifyImage/Z [0] ctab= {*,*,Terrain,0}
		ModifyGraph/Z mirror=0
	EndMacro
